@@ -1,12 +1,13 @@
 .onLoad <- function(libname, pkgname)
 {
-  #.jpackage(pkgname)  # not necessary anymore
+  require(rJava)
+  .jpackage(pkgname)  # needed to load RInterface.java
   
   # what's your java  version?  Need > 1.5.0.
-##   jversion <- .jcall('java.lang.System','S','getProperty','java.version')
-##   if (jversion <= "1.5.0")
-##     stop(paste("Your java version is ", jversion,
-##                  ".  Need 1.5.0 or higher.", sep=""))
+  jversion <- .jcall('java.lang.System','S','getProperty','java.version')
+  if (jversion < "1.5.0")
+    stop(paste("Your java version is ", jversion,
+                 ".  Need 1.5.0 or higher.", sep=""))
 
   #wb <- createWorkbook()   # load/initialize jars here as it takes 
   #rm(wb)                   # a few seconds ...
