@@ -2,14 +2,14 @@
 #
 #
 
-test.workbook <- function()
+test.workbook <- function(type="xlsx")
 {
   cat("##################################################\n")
   cat("Testing basic workbook functions\n")
   cat("##################################################\n")
 
   cat("Create an empty workbook ... ") 
-  wb <- createWorkbook()
+  wb <- createWorkbook(type=type)
   cat("OK\n")
 
   cat("Create a sheet called 'Sheet1' ... ")
@@ -37,7 +37,8 @@ test.workbook <- function()
   cat("OK\n")
 
   cat("Remove rows 1:10 on Sheet1 of test_import.xlsx ... ")
-  file <- system.file("tests", "test_import.xlsx", package = "xlsx")
+  filename <- paste("test_import.", type, sep="")
+  file <- system.file("tests", filename, package="xlsx")
   wb <- loadWorkbook(file)  
   sheets <- getSheets(wb)
   sheet <- sheets[[1]]  
@@ -47,9 +48,6 @@ test.workbook <- function()
   stopifnot(length(rows) == 41)
   cat("OK\n")
   
-  
-  
-  
 }
 
 
